@@ -13,12 +13,13 @@ from aws_lambda_powertools.helper.models import MetricUnit
 from .exceptions import MetricUnitError, MetricValueError, SchemaValidationError, UniqueNamespaceError
 
 logger = logging.getLogger(__name__)
-logger.setLevel(os.getenv("LOG_LEVEL", "INFO"))
 
 _schema_path = pathlib.Path(__file__).parent / "./schema.json"
 with _schema_path.open() as f:
     CLOUDWATCH_EMF_SCHEMA = json.load(f)
 
+MAX_METRICS = 100
+
 
 class MetricManager:
     """Base class for metric functionality (namespace, metric, dimension, serialization)
@@ -52,6 +53,8 @@ class MetricManager:
         self.metric_set = metric_set or {}
         self.dimension_set = dimension_set or {}
         self.namespace = os.getenv("POWERTOOLS_METRICS_NAMESPACE") or namespace
+        self._metric_units = [unit.value for unit in MetricUnit]
+        self._metric_unit_options = list(MetricUnit.__members__)
 
     def add_namespace(self, name: str):
         """Adds given metric namespace
@@ -101,26 +104,20 @@ class MetricManager:
         MetricUnitError
             When metric unit is not supported by CloudWatch
         """
-        if len(self.metric_set) == 100:
-            logger.debug("Exceeded maximum of 100 metrics - Publishing existing metric set")
-            metrics = self.serialize_metric_set()
-            print(json.dumps(metrics))
-            self.metric_set = {}
-
         if not isinstance(value, numbers.Number):
             raise MetricValueError(f"{value} is not a valid number")
 
-        if not isinstance(unit, MetricUnit):
-            try:
-                unit = MetricUnit[unit]
-            except KeyError:
-                unit_options = list(MetricUnit.__members__)
-                raise MetricUnitError(f"Invalid metric unit '{unit}', expected either option: {unit_options}")
-
-        metric = {"Unit": unit.value, "Value": float(value)}
+        unit = self.__extract_metric_unit_value(unit=unit)
+        metric = {"Unit": unit, "Value": float(value)}
         logger.debug(f"Adding metric: {name} with {metric}")
         self.metric_set[name] = metric
 
+        if len(self.metric_set) == MAX_METRICS:
+            logger.debug(f"Exceeded maximum of {MAX_METRICS} metrics - Publishing existing metric set")
+            metrics = self.serialize_metric_set()
+            print(json.dumps(metrics))
+            self.metric_set = {}
+
     def serialize_metric_set(self, metrics: Dict = None, dimensions: Dict = None) -> Dict:
         """Serializes metric and dimensions set
 
@@ -149,10 +146,10 @@ class MetricManager:
         SchemaValidationError
             Raised when serialization fail schema validation
         """
-        if metrics is None:
+        if metrics is None:  # pragma: no cover
             metrics = self.metric_set
 
-        if dimensions is None:
+        if dimensions is None:  # pragma: no cover
             dimensions = self.dimension_set
 
         logger.debug("Serializing...", {"metrics": metrics, "dimensions": dimensions})
@@ -164,11 +161,10 @@ class MetricManager:
         for metric_name in metrics:
             metric: str = metrics[metric_name]
             metric_value: int = metric.get("Value", 0)
-            metric_unit: str = metric.get("Unit")
+            metric_unit: str = metric.get("Unit", "")
 
-            if metric_value > 0 and metric_unit is not None:
-                metric_names_unit.append({"Name": metric_name, "Unit": metric["Unit"]})
-                metric_set.update({metric_name: metric["Value"]})
+            metric_names_unit.append({"Name": metric_name, "Unit": metric_unit})
+            metric_set.update({metric_name: metric_value})
 
         metrics_definition = {
             "CloudWatchMetrics": [
@@ -205,3 +201,36 @@ class MetricManager:
         """
         logger.debug(f"Adding dimension: {name}:{value}")
         self.dimension_set[name] = value
+
+    def __extract_metric_unit_value(self, unit: Union[str, MetricUnit]) -> str:
+        """Return metric value from metric unit whether that's str or MetricUnit enum
+
+        Parameters
+        ----------
+        unit : Union[str, MetricUnit]
+            Metric unit
+
+        Returns
+        -------
+        str
+            Metric unit value (e.g. "Seconds", "Count/Second")
+
+        Raises
+        ------
+        MetricUnitError
+            When metric unit is not supported by CloudWatch
+        """
+
+        if isinstance(unit, str):
+            if unit in self._metric_unit_options:
+                unit = MetricUnit[unit].value
+
+            if unit not in self._metric_units:  # str correta
+                raise MetricUnitError(
+                    f"Invalid metric unit '{unit}', expected either option: {self._metric_unit_options}"
+                )
+
+        if isinstance(unit, MetricUnit):
+            unit = unit.value
+
+        return unit
